#!/bin/bash
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 18-06-2007
# source location  : http://xml.apache.org/xalan-j/
# url              : http://www.apache.org/dist/xml/xalan-j/xalan-j_2_7_0-bin.tar.gz

NAME=xalan-java
VERSION=2.7.0
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-48.2}
TMP=${TMP:-/tmp}
PKG=$TMP/package-$NAME
CWD=`pwd`
EXTENSION=tar.gz
FILENAME=${NAME/-java/}-j_${VERSION//./_}-bin.$EXTENSION

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
#numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf ${NAME/-java/}-j_${VERSION//./_}
  if [ -f $FILENAME ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/$FILENAME ]; then
          echo -n "Relocating source file to $TMP..."
          cp $CWD/$FILENAME $TMP/
	  echo "done"
  else
	  wget -c http://www.apache.org/dist/xml/xalan-j/$FILENAME
  fi
  tar xvf $FILENAME

cd ${NAME/-java/}-j_${VERSION//./_}

# Build and install:
mkdir -p $PKG/usr/lib/java
install -m644 ${NAME/-java/}.jar $PKG/usr/lib/java/

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress the man page(s)
if [ -d $PKG/usr/man ]; then
	find $PKG/usr/man -type f -name "*.?" -exec gzip -9f {} \;
fi
if [ -d $PKG/usr/info ]; then
	find $PKG/usr/info -type f -name "*.info*" -exec gzip -9f {} \;
fi

# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

# The Makefile evidently contains the package's license...
DOCS="readme.html ${NAME/-java/}.README.txt"
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

# 
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

mkdir -p $PKG/install

#    |-----handy-ruler------------------------------------------------------|
echo "$NAME: $NAME (Xalan-Java is an XSLT processor)
$NAME:
$NAME: Xalan-Java is an XSLT processor for transforming XML documents into
$NAME: HTML, text, or other XML document types. It implements XSL
$NAME: Transformations (XSLT) Version 1.0 and XML Path Language (XPath)
$NAME: Version 1.0.
$NAME:
$NAME: 
$NAME: 
$NAME:
$NAME: " > $PKG/install/slack-desc

#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
cd $TMP
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
echo "jre|jdk" > $NAME-$VERSION-$ARCH-$BUILD.dep

